pub async fn create_test_environment(
setup_db: bool,
setup_rpc: bool,
) -> (TxSenderConfig, Option<TxSenderDb>, Option<WithProcessCleanup>)Expand description
Creates a test environment with a unique database name and a regtest Bitcoin node specific to the test.